#[repr(transparent)]pub struct ActionButton {
inner: TypedObjectRef<ActionButton, <ActionButton as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
A button to emit an action and handle its different states.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<ActionButton, <ActionButton as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl ActionButton
impl ActionButton
Sourcepub fn icon_name(&self) -> <RefCell<String> as Property>::Value
pub fn icon_name(&self) -> <RefCell<String> as Property>::Value
The icon used in the default state.
Sourcepub fn set_icon_name<'a>(
&self,
value: impl Borrow<<<RefCell<String> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_icon_name<'a>( &self, value: impl Borrow<<<RefCell<String> as Property>::Value as HasParamSpec>::SetValue>, )
The icon used in the default state.
Sourcepub fn set_state<'a>(
&self,
value: impl Borrow<<<Cell<ActionState> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_state<'a>( &self, value: impl Borrow<<<Cell<ActionState> as Property>::Value as HasParamSpec>::SetValue>, )
The state of the button.
Sourcepub fn set_default_state_tooltip_text<'a>(
&self,
value: impl Borrow<<<PhantomData<Option<String>> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_default_state_tooltip_text<'a>( &self, value: impl Borrow<<<PhantomData<Option<String>> as Property>::Value as HasParamSpec>::SetValue>, )
The tooltip text of the button of the default state.
Sourcepub fn connect_icon_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_icon_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the icon-name property
Sourcepub fn connect_state_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_state_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the state property
Sourcepub fn connect_default_state_tooltip_text_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_default_state_tooltip_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the default-state-tooltip-text property
Sourcepub fn notify_icon_name(&self)
pub fn notify_icon_name(&self)
Notify listeners of a change in the icon-name property
Sourcepub fn notify_state(&self)
pub fn notify_state(&self)
Notify listeners of a change in the state property
Sourcepub fn notify_default_state_tooltip_text(&self)
pub fn notify_default_state_tooltip_text(&self)
Notify listeners of a change in the default-state-tooltip-text property
Sourceimpl ActionButton
impl ActionButton
pub fn new() -> Self
Sourcepub(crate) fn set_extra_classes(&self, classes: &[&'static str])
pub(crate) fn set_extra_classes(&self, classes: &[&'static str])
Set the extra CSS classes applied to the button in the default state.
Sourcepub fn connect_clicked<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_clicked<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Connect to the signal emitted when the button is clicked.